@@ -16,7 +16,7 @@ def _load_default_settings():
 
 def _setup_loggers():
     from logging import addLevelName, Logger, config
-    from os.path import join, abspath
+    from os.path import join, abspath, expanduser
     from inspect import getsourcefile
 
     protocol_level = 55
@@ -26,8 +26,9 @@ def _setup_loggers():
         if self.isEnabledFor(protocol_level):
             self._log(protocol_level, message, args, **kwargs)
     Logger.protocol = protocol
-    logging_config = join(abspath(getsourcefile(lambda: None))[:-11],
-                          "static/logging.ini")
+    user_path = expanduser("~")
+    logging_config = join(user_path,
+                          ".conML/logging.ini")
     config.fileConfig(logging_config)
 
 
